status property
The encryption status. While the status is UPDATING, X-Ray may
encrypt data with a combination of the new and old settings.
Implementation
final EncryptionStatus? status;
The encryption status. While the status is UPDATING, X-Ray may
encrypt data with a combination of the new and old settings.
final EncryptionStatus? status;